# Copyright (C) 2009 Ferdinand Majerech
# This file is part of IMGCrush
# For conditions of distribution and use, see copyright notice in __init__.py

from util import *

class JPGSettings:
    """Stores settings of a JPG file to generate.
    """ 
    def __init__(self, quality, interlace, optimize, samplingfactor):
        """Constructor.

        Data members:
        Quality        : Quality level of jpg compression - higher means 
                         higher quality and filesize. Valid values : int 0-100
        Interlace      : Should this image be interlaced (progressive) ?
        Optimize       : Should this image be compressed with optimizations
                         (usually results in smaller filesize) ?
        SamplingFactor : Subsampling factor used on this image.
        """
        self.Quality = quality
        self.Interlace = interlace
        self.Optimize = optimize
        self.SamplingFactor = samplingfactor

class PNGSettings:
    """Stores settings of a PNG file to generate
    """ 
    def __init__(self, level, filt, mode, bitdepth, interlace):
        """Constructor.

        Level     : Compression level of this image -higher means lower size.
        Filter    : PNG filter used for this image.
        Mode      : Color mode of this image. e.g. truecolor, palette, etc.
        BitDepth  : Bit depth of every channel of this image.
        Interlace : Should this image be interlaced (progressive) ?
        """
        self.Level = level
        self.Filter = filt
        self.Mode = mode
        self.BitDepth = bitdepth
        self.Interlace = interlace

class GIFSettings:
    """Stores settings of a GIF file to generate
    """ 
    def __init__(self, interlace):
        """Constructor.
        
        Interlace : Should this image be interlaced (progressive) ?
        """
        self.Interlace = interlace
