# Copyright (C) 2009 Ferdinand Majerech
# This file is part of IMGCrush
# For conditions of distribution and use, see copyright notice in __init__.pyfrom util import *

from imagesettings import *

class ReferenceFile:
    """Stores data about reference and input files used to generate output.
    """
    def __init__(self, infname, fname, w, h, fill, stretch, bgcolor):
        """Constructor.

        Creates the reference file.
        
        Data members:
        Name      : Filename of the reference file.
        InputSize : Size of the input file.
        Size      : Size of the reference file.
        Width     : Width of the reference file in px.
        Height    : Height of the reference file in px.
        Colors    : Count of unique colors in the file.
        """
        self.Name = fname    
        inparams = run_bash("identify -format \"%b %w %h\" " +\
                            infname).split(" ")
        self.InputName = infname
        self.InputSize = int(inparams[0])
        if w or h:
            inwidth = int(inparams[1])
            inheight = int(inparams[2])
            if w and w[-1] == "%":
                w = clamp(int(inwidth * float(w[:-1]) / 100.0), 1, 1048576)
            if h and h[-1] == "%":
                h = clamp(int(inheight * float(h[:-1]) / 100.0), 1, 1048576)
        imagick_cmd("png", PNGSettings(9, 6, "truecolor", 8, False), infname, 
                   self.Name, [w, h, fill, stretch, bgcolor])
        refparams = run_bash("identify -format \"%b %w %h %k\" " + self.Name)\
                            .split(" ")
        self.Size = int(refparams[0])
        self.Width = int(refparams[1])
        self.Height = int(refparams[2])
        self.Colors = int(refparams[3])
