# Copyright (C) 2009 Ferdinand Majerech
# This file is part of IMGCrush
# For conditions of distribution and use, see copyright notice in __init__.py

from util import *

class TempImage:
    """Stores data about a generated temporary image file.
    """

    def __init__(self, filename, filetype, settings, reffile):
        """Constructor.

        Creates the temporary file and measures it's properties.

        Data members:
        FileName     : File name of the generated image.
        FileType     : File type of the generated image (i.e. jpg, png or gif).
        TypeSettings : Settings specific to file type with which the file
                       was generated. Stored as JPGSettings, PNGSettings or 
                       GIFSettings.
        Size         : Size of the generated image in bytes.
        PercentSize  : Size if % of size of reference file.
        Quality      : Quality of this file in %.
        """
        self.FileName = filename
        self.FileType = filetype
        self.TypeSettings = settings
        imagick_cmd(filetype, settings, reffile.Name, self.FileName)
        refsize = reffile.Size
        self.Size = int(run_bash("stat -c%s " + self.FileName))
        #TODO: undecided - also add percent size compared to uncompressed truecolor images (i.e. like bmp or tga) 
        self.PercentSizeRef = float(self.Size) / float(refsize)
        if filename.find("__lossless__") >= 0:
            self.Quality = 100.0
        else:
            self.Quality = 100.0 - (100 * float(
                           run_bash("compare -metric mae "+ reffile.Name + " " +\
                                   self.FileName+" /dev/null",True)\
                                   .split(" ")[1][1:-1]))

